@@ -18,23 +18,24 @@ This utility finds is based on the zope importchecker script, prints
 out unused imports, imports that are only for tests packages and
 runtime imports.
 
-$Id: importchecker.py 5077 2021-01-21 13:15:46Z roger.ineichen $
+$Id: importchecker.py 5091 2021-01-22 14:17:52Z roger.ineichen $
 """
-try:
-    # compiler
-    from p01.recipe.setup.importchecker2 import ImportDatabase
-except ImportError:
-    # ast
-    from p01.recipe.setup.importchecker3 import ImportDatabase
+
 import os
 import os.path
 import sys
 
-from p01.recipe.setup import LoggerMixin
-
 import zc.buildout
 import zc.recipe.egg
 
+import p01.recipe.setup
+if sys.version_info.major == 2:
+    # compiler
+    from p01.recipe.setup.importchecker2 import ImportDatabase
+else:
+    # ast
+    from p01.recipe.setup.importchecker3 import ImportDatabase
+
 
 initialization_template = """import os
 sys.argv[0] = os.path.abspath(sys.argv[0])
@@ -44,7 +45,7 @@ env_template = """os.environ['%s'] = %r
 """
 
 
-class ImportCheckerRecipe(LoggerMixin):
+class ImportCheckerRecipe(p01.recipe.setup.LoggerMixin):
     """Import checker recipe."""
 
     def __init__(self, buildout, name, options):
@@ -77,7 +78,7 @@ class ImportCheckerRecipe(LoggerMixin):
         env_section = self.options.get('environment', '').strip()
         if env_section:
             env = self.buildout[env_section]
-            for key, value in env.items():
+            for key, value in list(env.items()):
                 initialization += env_template % (key, value)
 
         # setup checker script
@@ -115,7 +116,7 @@ def checker(path):
     db = ImportDatabase(path)
     db.findModules()
     unused_imports = db.getUnusedImports()
-    module_paths = unused_imports.keys()
+    module_paths = list(unused_imports.keys())
     module_paths.sort()
     print("="*79)
     print("unused imports:")
@@ -130,7 +131,7 @@ def checker(path):
             names = line2names.get(line, [])
             names.append(name)
             line2names[line] = names
-        lines = line2names.keys()
+        lines = list(line2names.keys())
         lines.sort()
         for line in lines:
             names = ', '.join(line2names[line])
